@@ -1,7 +1,7 @@
 import argparse
 import sys
 from qrunner import __version__, __description__
-from qrunner.scaffold import init_parser_scaffold, main_scaffold
+from qrunner.scaffold import init_parser_scaffold, init_parser_scaffold_ios, main_scaffold, main_scaffold_ios
 
 
 def main():
@@ -14,6 +14,7 @@ def main():
 
     subparsers = parser.add_subparsers(help="sub-command help")
     sub_parser_scaffold = init_parser_scaffold(subparsers)
+    sub_parser_scaffold_ios = init_parser_scaffold_ios(subparsers)
 
     if len(sys.argv) == 1:
         # qrunner
@@ -33,6 +34,9 @@ def main():
         elif sys.argv[1] == "startproject":
             # httprunner startproject
             sub_parser_scaffold.print_help()
+        elif sys.argv[1] == "start_ios_project":
+            # httprunner startproject
+            sub_parser_scaffold_ios.print_help()
         sys.exit(0)
 
     args = parser.parse_args()
@@ -42,6 +46,8 @@ def main():
 
     if sys.argv[1] == "startproject":
         main_scaffold(args)
+    elif sys.argv[1] == "start_ios_project":
+        main_scaffold_ios(args)
 
 
 if __name__ == "__main__":
