@@ -10,20 +10,35 @@ d = driver.d
 
 # 安卓原生元素
 class Element:
-    def __init__(self, rid=None, text=None, xpath=None, index=None):
-        self.element_loc = {'resourceId': rid, 'text': text, 'xpath': xpath, 'index': index}
+    def __init__(self,
+                 rid=None,
+                 className=None,
+                 text=None,
+                 textContains=None,
+                 xpath=None,
+                 index=None
+                 ):
+        self.element_loc = {'resourceId': rid, 'className': className, 'text': text, 'textContains': textContains, 'xpath': xpath, 'index': index}
         self.element_loc = {k: v for k, v in self.element_loc.items() if v is not None}  # 去除为None的定位器
-        if xpath:
-            self.element = d.xpath(xpath)
+        if rid and text:
+            self.element = d(resourceId=rid, text=text)
+        elif rid and textContains:
+            self.element = d(resourceId=rid, textContains=textContains)
         else:
-            if rid and text:
-                self.element = d(resourceId=rid, text=text)
-            elif rid and not text:
+            if rid:
                 self.element = d(resourceId=rid)
-            elif not rid and text:
+            elif xpath:
+                self.element = d(xpath=xpath)
+            elif text:
                 self.element = d(text=text)
-            if index:
-                self.element = self.element[index]
+            elif textContains:
+                self.element = d(textContains=textContains)
+            elif className:
+                self.element = d(className=className)
+            else:
+                logger.info('暂不支持的定位方式')
+        if index:
+            self.element = self.element[index]
 
     def wait(self, timeout=10, shot_flag=True):
         if self.element.wait(timeout=timeout):
@@ -60,6 +75,8 @@ class Element:
         logger.info(f'定位元素并输入{content}: {self.element_loc}')
         if self.wait():
             self.element.send_keys(content)
+            d.send_action('search')
+            d.set_fastinput_ime(False)
 
     def get_text(self):
         logger.info(f'获取元素文本: {self.element_loc}')
