@@ -46,6 +46,10 @@ class Driver(object):
         else:
             self.serial_no = serial_no
         self.bundle_id = conf.get_name('app', 'pkg_name')
+        logger.info(f'启动webdriver for {self.serial_no}')
+        ws = WDAServer(self.serial_no)
+        ws.launch_wda()
+        logger.info(f'连接手机: {self.serial_no}')
         self.d = wda.USBClient(self.serial_no, port=8100)
 
     def uninstall_app(self, bundle_id=None):
@@ -147,7 +151,7 @@ class Driver(object):
         rgb_im.save(img_path)
 
     @relaunch_wda
-    def allure_shot(self, filename, timeout=3):
+    def allure_shot(self, filename, timeout=1):
         logger.info(f'{filename}-截图')
         time.sleep(timeout)
         self.screenshot('tmp.png')
