@@ -9,25 +9,52 @@ d = driver.d
 
 
 class Element:
-    def __init__(self, name=None, value=None, xpath=None, index=None, label=None, labelContains=None):
+    def __init__(self, name=None,
+                 nameContains=None,
+                 value=None,
+                 valueContains=None,
+                 xpath=None,
+                 index=None,
+                 label=None,
+                 labelContains=None,
+                 className=None):
         self.element_loc = {
             'name': name,
+            'nameContains': nameContains,
             'value': value,
+            'valueContains': valueContains,
             'xpath': xpath,
             'label': label,
+            'labelContains': labelContains,
+            'className': className,
             'index': index
         }
         self.element_loc = {k: v for k, v in self.element_loc.items() if v is not None}  # 去除为None的定位器
-        if xpath:
-            self.element = d.xpath(xpath)
-        elif name:
-            self.element = d(name=name)
-        elif value:
-            self.element = d(value=value)
-        elif label:
-            self.element = d(label=label)
-        elif labelContains:
-            self.element = d(labelContains=labelContains)
+        if xpath and name:
+            self.element = d(xpath=xpath, name=name)
+        elif xpath and nameContains:
+            self.element = d(xpath=xpath, nameContains=nameContains)
+        elif name and className:
+            self.element = d(name=name, className=className)
+        else:
+            if xpath:
+                self.element = d(xpath=xpath)
+            elif name:
+                self.element = d(name=name)
+            elif nameContains:
+                self.element = d(nameContains=nameContains)
+            elif label:
+                self.element = d(label=label)
+            elif labelContains:
+                self.element = d(labelContains=labelContains)
+            elif value:
+                self.element = d(value)
+            elif valueContains:
+                self.element = d(valueContains=valueContains)
+            elif className:
+                self.element = d(className=className)
+            else:
+                logger.info('暂不支持的定位方式')
         if index:
             self.element = self.element[index]
 
@@ -84,5 +111,11 @@ class Element:
         else:
             return None
 
+    @relaunch_wda
+    def scroll(self):
+        logger.info(f'滚动到该元素: {self.element_loc}')
+        if self.wait():
+            self.element.scroll()
+
 
 
