@@ -1,8 +1,8 @@
 import requests
 from selenium import webdriver
-from utils.log import logger
-from utils.config import conf
-from core.android.element import driver
+from qrunner.utils.log import logger
+from conf.config import conf
+from qrunner.core.android.element import driver
 
 
 # 重启chromedriver的装饰器
