@@ -1,5 +1,5 @@
-from utils.log import logger
-from core.web.driver import relaunch
+from qrunner.utils.log import logger
+from qrunner.core.web.driver import relaunch
 from selenium.webdriver.common.by import By
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support.wait import WebDriverWait
