@@ -14,32 +14,42 @@ def init_parser_scaffold(subparsers):
     return sub_parser_scaffold
 
 
-def create_scaffold(project_name):
+def init_parser_scaffold_ios(subparsers):
+    sub_parser_scaffold = subparsers.add_parser(
+        "start_ios_project", help="Create a ios project with template structure."
+    )
+    sub_parser_scaffold.add_argument(
+        "project_name", type=str, nargs="?", help="Specify new project name."
+    )
+    return sub_parser_scaffold
+
+
+def create_scaffold(platform, project_name):
     """ create scaffold with specified project name.
     """
 
-    def show_tree(prj_name):
-        try:
-            print(f"\n$ tree {prj_name} -a")
-            subprocess.run(["tree", prj_name, "-a"])
-            print("")
-        except FileNotFoundError:
-            logger.warning("tree command not exists, ignore.")
+    # def show_tree(prj_name):
+    #     try:
+    #         print(f"\n$ tree {prj_name}")
+    #         subprocess.run(["tree", prj_name])
+    #         print("")
+    #     except FileNotFoundError:
+    #         logger.warning("tree command not exists, ignore.")
 
-    if os.path.isdir(project_name):
-        logger.warning(
-            f"Project folder {project_name} exists, please specify a new project name."
-        )
-        show_tree(project_name)
-        return 1
-    elif os.path.isfile(project_name):
-        logger.warning(
-            f"Project name {project_name} conflicts with existed file, please specify a new one."
-        )
-        return 1
+    # if os.path.isdir(project_name):
+    #     logger.warning(
+    #         f"Project folder {project_name} exists, please specify a new project name."
+    #     )
+    #     show_tree(project_name)
+    #     return 1
+    # elif os.path.isfile(project_name):
+    #     logger.warning(
+    #         f"Project name {project_name} conflicts with existed file, please specify a new one."
+    #     )
+    #     return 1
 
-    logger.info(f"Create new project: {project_name}")
-    print(f"Project Root Dir: {os.path.join(os.getcwd(), project_name)}\n")
+    # logger.info(f"Create new project: {project_name}")
+    # print(f"Project Root Dir: {os.path.join(os.getcwd(), project_name)}\n")
 
     def create_folder(path):
         os.makedirs(path)
@@ -76,7 +86,10 @@ conf.set_name('app', 'pkg_url', args.pkg_url)
 pytest.main(['tests', '--reruns', '1 ', '-s', '-v', '--alluredir', 'allure-results',
              '--clean-alluredir', '--html=report.html', '--self-contained-html'])
 """
-    demo_conftest = """
+    demo_conftest = ""
+    demo_page = ""
+    if platform == 'android':
+        demo_conftest = """
 import pytest
 from qrunner.core.android.element import driver, Element as E
 from qrunner.utils.log import logger
@@ -116,17 +129,72 @@ def init_case():
     logger.info('停止应用')
     driver.stop_app()
 """
-    demo_page = """
+        demo_page = """
 from qrunner.core.android.element import Element, driver
 
 
 class HomePage:
     bottom_peer = Element(rid='com.qizhidao.clientapp:id/icon2')
+    
+    def go_peer(self):
+        self.bottom_peer.click()
+        driver.allure_shot('查同行')
+"""
+    elif platform == 'ios':
+        demo_conftest = """
+import pytest
+from qrunner.utils.log import logger
+from conf.config import conf
+from qrunner.core.ios.element import driver, Element
+
+
+# 安装应用
+@pytest.fixture(scope='session', autouse=True)
+def install_app():
+    if conf.get_name('app', 'need_install') == 'yes':
+        pkg_url = conf.get_name('app', 'pkg_url')
+        logger.info(f'安装应用: {pkg_url}')
+        driver.install_app(pkg_url, is_new=True)
+    else:
+        logger.info('无需安装应用')
+
+# 初始化权限
+@pytest.fixture(scope='session', autouse=True)
+def init_app(install_app):
+    if conf.get_name('app', 'need_install') == 'yes':
+        pass
+    else:
+        logger.info('无需初始化应用')
+
+# 用例的前置和后置操作
+@pytest.fixture(scope='function', autouse=True)
+def init_case():
+    # 启动应用
+    logger.info('用例开始: 启动应用')
+    driver.force_start_app()
+    element = Element(name='以后再说')
+    if element.exists(1):
+        element.click()
+    yield
+    # 截图
+    logger.info('用例结束: 进行截图')
+    driver.allure_shot('用例结束')
+    # 停止应用
+    logger.info('用例结束: 退出应用')
+    driver.stop_app()
+"""
+        demo_page = """
+from qrunner.core.ios.element import Element, driver
+
+
+class HomePage:
+    bottom_peer = Element(name='查同行', index=2)
 
     def go_peer(self):
         self.bottom_peer.click()
         driver.allure_shot('查同行')
 """
+
     demo_case = """
 import allure
 from pages.demo_page import HomePage
@@ -139,8 +207,9 @@ class TestPeerSearch:
     def test(self):
         HomePage().go_peer()
 """
+
     ignore_content = "\n".join(
-        [".env", "allure-results/*", "__pycache__/*", "*.pyc", ".python-version", "logs/*", "report.html", ".idea/*"]
+        ["allure-results/*", "__pycache__/*", "*.pyc", "report.html", ".idea/*"]
     )
 
     config_content = """
@@ -154,7 +223,6 @@ pkg_url =
 """
     config_handle = """
 import os
-import pathlib
 import configparser
 
 local_path = os.path.dirname(os.path.realpath(__file__))
@@ -163,8 +231,6 @@ local_path = os.path.dirname(os.path.realpath(__file__))
 class Config:
     def __init__(self):
         self.conf_file_path = os.path.join(local_path, 'config.ini')
-        config_file = pathlib.Path(self.conf_file_path)
-        config_file.touch(exist_ok=True)
         self.cf = configparser.ConfigParser()
         self.cf.read(self.conf_file_path, encoding='utf-8')
 
@@ -186,6 +252,10 @@ class Config:
 
 # 初始化
 conf = Config()
+"""
+
+    require_content = """
+qrunner
 """
 
     create_folder(project_name)
@@ -221,11 +291,18 @@ conf = Config()
         os.path.join(project_name, ".gitignore"),
         ignore_content,
     )
+    create_file(
+        os.path.join(project_name, "requirements.txt"),
+        require_content,
+    )
 
-    show_tree(project_name)
+    # show_tree(project_name)
     return 0
 
 
 def main_scaffold(args):
-    sys.exit(create_scaffold(args.project_name))
+    sys.exit(create_scaffold('android', args.project_name))
 
+
+def main_scaffold_ios(args):
+    sys.exit(create_scaffold('ios', args.project_name))
